@@ -1,19 +1,15 @@
 from abc import *
-
 import os
 import sys
 import json
 import cv2 as cv
+import numpy as np
 from io import BytesIO
+import tensorflow as tf
+import tensorflow_datasets as tfds
 from google.cloud import storage
 from google.cloud.storage import Blob
-import tensorflow_datasets as tfds
-
-import json
-import numpy as np
-import tensorflow as tf
 from sklearn.model_selection import train_test_split
-
 from .. import global_variable as gv
 from . import dataset_mgmt as dsmgmt
 
@@ -56,33 +52,33 @@ class MiddleDatasetMgmt(dsmgmt.DatasetMgmt):
     
     ###
     def make_bucket(self, bucket_name):
-        print(f"{sys._getframe(0).f_code.co_name} function called")
+        self.log.info(f"{sys._getframe(0).f_code.co_name} function called")
         
         try:
             self.client.get_bucket(bucket_name) #lockup_bucket을 대신 사용할 수도 있음
-            print(f"{bucket_name} bucket already exists")
+            self.log.info(f"{bucket_name} bucket already exists")
         except:
-            print(f"{bucket_name} bucket doesn't exists")
+            self.log.info(f"{bucket_name} bucket doesn't exists")
             bucket = self.client.bucket(bucket_name)
             bucket.storage_class = "STANDARD"
             
             #mb : make bucket (PROJECT_ID와 REGION에 종속된 DATA_BUCKET 생성)
             #!gsutil mb -p $self.gv.PROJECT_ID -c standard -l $self.gv.REGION gs://$gv.DATA_BUCKET 
             new = self.client.create_bucket(bucket, project=self.gv.PROJECT_ID, location=self.gv.REGION)
-            print(f"Created bucket {new.name} in {new.location} with storage class {new.storage_class}")  
+            self.log.info(f"Created bucket {new.name} in {new.location} with storage class {new.storage_class}")  
         
     
     def download(self, dataset_name):
-        print("under contruction")
+        self.log.info("under contruction")
     
     
     def upload(self, bucket_name):
-        print("under contruction")
+        self.log.info("under contruction")
     
     
     ###
     def read(self, bucket_name): #TFRecord format
-        print("under contruction")
+        self.log.info("under contruction")
     
     
     def read_and_split(self, bucket_name, dataset_size, data_split): #TFRecord format : storing a sequence of binary records
@@ -167,18 +163,18 @@ class TensorflowDatasetMgmt(MiddleDatasetMgmt):
 class COCODatasetMgmt(MiddleDatasetMgmt):
     
     def download(self, dataset_name):
-        print("under contruction")
+        self.log.info("under contruction")
     
     
     def upload(self, bucket_name):
         self.bucket_name = bucket_name
-        print("under contruction")
+        self.log.info("under contruction")
     
     
     def __upload_dataset_to_bucket(self, dataset, data_type_name):
-        print("under contruction")
+        self.log.info("under contruction")
         
         
     def __upload_dataset_label_to_bucket(self, dataset_list): 
-        print("under contruction")
+        self.log.info("under contruction")
     
\ No newline at end of file
